==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/instanceaccess/impl/AssignToMemberSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instanceaccess.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.AssignToMember;
import io.ciera.tool.sql.ooaofooa.instanceaccess.AssignToMemberSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class AssignToMemberSetImpl extends InstanceSet<AssignToMemberSet,AssignToMember> implements AssignToMemberSet {

    // attributes
    @Override
    public void setAttributeLineNumber( int m_attributeLineNumber ) throws XtumlException {
        for ( AssignToMember assigntomember : this ) assigntomember.setAttributeLineNumber( m_attributeLineNumber );
    }
    @Override
    public void setR_Value_ID( UniqueId ref_r_Value_ID ) throws XtumlException {
        for ( AssignToMember assigntomember : this ) assigntomember.setR_Value_ID( ref_r_Value_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( AssignToMember assigntomember : this ) assigntomember.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setAttributeColumn( int m_attributeColumn ) throws XtumlException {
        for ( AssignToMember assigntomember : this ) assigntomember.setAttributeColumn( m_attributeColumn );
    }
    @Override
    public void setL_Value_ID( UniqueId ref_l_Value_ID ) throws XtumlException {
        for ( AssignToMember assigntomember : this ) assigntomember.setL_Value_ID( ref_l_Value_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( AssignToMember assigntomember : this ) act_smtset.add( assigntomember.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public ValueSet R609_reads_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( AssignToMember assigntomember : this ) valueset.add( assigntomember.R609_reads_Value() );
        return valueset;
    }
    @Override
    public ValueSet R689_writes_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( AssignToMember assigntomember : this ) valueset.add( assigntomember.R689_writes_Value() );
        return valueset;
    }


    @Override
    public AssignToMember nullElement() {
        return AssignToMemberImpl.EMPTY_ASSIGNTOMEMBER;
    }

    @Override
    public AssignToMemberSet emptySet() {
      return new AssignToMemberSetImpl();
    }

    @Override
    public AssignToMemberSet value() {
        return this;
    }

    @Override
    public List<AssignToMember> elements() {
        return Arrays.asList(toArray(new AssignToMember[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/instanceaccess/impl/AssignToMemberSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instanceaccess.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.AssignToMember;
import io.ciera.tool.sql.ooaofooa.instanceaccess.AssignToMemberSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class AssignToMemberSetImpl extends InstanceSet<AssignToMemberSet,AssignToMember> implements AssignToMemberSet {

    public AssignToMemberSetImpl() {
    }

    public AssignToMemberSetImpl(Comparator<? super AssignToMember> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAttributeLineNumber( int m_attributeLineNumber ) throws XtumlException {
        for ( AssignToMember assigntomember : this ) assigntomember.setAttributeLineNumber( m_attributeLineNumber );
    }
    @Override
    public void setR_Value_ID( UniqueId ref_r_Value_ID ) throws XtumlException {
        for ( AssignToMember assigntomember : this ) assigntomember.setR_Value_ID( ref_r_Value_ID );
    }
    @Override
    public void setL_Value_ID( UniqueId ref_l_Value_ID ) throws XtumlException {
        for ( AssignToMember assigntomember : this ) assigntomember.setL_Value_ID( ref_l_Value_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( AssignToMember assigntomember : this ) assigntomember.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setAttributeColumn( int m_attributeColumn ) throws XtumlException {
        for ( AssignToMember assigntomember : this ) assigntomember.setAttributeColumn( m_attributeColumn );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( AssignToMember assigntomember : this ) act_smtset.add( assigntomember.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public ValueSet R609_reads_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( AssignToMember assigntomember : this ) valueset.add( assigntomember.R609_reads_Value() );
        return valueset;
    }
    @Override
    public ValueSet R689_writes_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( AssignToMember assigntomember : this ) valueset.add( assigntomember.R689_writes_Value() );
        return valueset;
    }


    @Override
    public AssignToMember nullElement() {
        return AssignToMemberImpl.EMPTY_ASSIGNTOMEMBER;
    }

    @Override
    public AssignToMemberSet emptySet() {
      return new AssignToMemberSetImpl();
    }

    @Override
    public AssignToMemberSet emptySet(Comparator<? super AssignToMember> comp) {
      return new AssignToMemberSetImpl(comp);
    }

    @Override
    public AssignToMemberSet value() {
        return this;
    }

    @Override
    public List<AssignToMember> elements() {
        return Arrays.asList(toArray(new AssignToMember[0]));
    }

}
